% adc.m - 2's complement successive approximation ADC
%
% Usage: b = dac(x,B,R)
%
% x = Nx1 column vector of voltage values to be converted 
% B = number of bits
% R = full-scale voltage range [-R/2, R/2)
%
% b = NxB matrix of 2's complement B-bit row vectors = [b(1),b(2),...b(B)]

% S. J. Orfanidis - 1999 

function b = adc(x,B,R)

if nargin==0, help adc; return; end

x = x(:);
N = length(x);
b = zeros(N,B);

Q = R/2^B;

y = x + Q/2;                    % shift for rounding

b(:,1) = (y<0);                 % fix the sign bits of all the x's

for i=2:B,                      % test and fix remaining bits
 	b(:,i)= 1;                  % turn in i-th bit for testing
	xq = dac(b,B,R);            % test level
    b(:,i) = (y - xq) >= 0;     % correct bit is the comparator output
end






