% dac.m - 2's complement DAC
%
% Usage: xq = dac(b,B,R)
%
% b = NxB matrix of 2's complement B-bit row vectors = [b(1),b(2),...b(B)]
% B = number of bits
% R = full-scale voltage range [-R/2, R/2)
% 
% xq = N-dimensional column vector of quantized voltage values

% S. J. Orfanidis - 1999 

function xq = dac(b,B,R)

if nargin==0, help dac; return; end

N = size(b,1); 
xq = zeros(N,1);

b(:,1) = 1 - b(:,1);                % complement first bit

for i = B : -1 : 1,
    xq = 0.5 * (xq + b(:,i));       % Horner's rule
end

xq  = R*(xq-0.5);             % adjust baseline and scale

